@@ -7,12 +7,7 @@ import (
 	"github.com/caddyserver/caddy"
 )
 
-func init() {
-	caddy.RegisterPlugin("metadata", caddy.Plugin{
-		ServerType: "dns",
-		Action:     setup,
-	})
-}
+func init() { plugin.Register("metadata", setup) }
 
 func setup(c *caddy.Controller) error {
 	m, err := metadataParse(c)
